==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/content/messages/de/base.php <==
<?php
return array (
  '<strong>Confirm</strong> post deletion' => '<strong>Bestätige</strong> Beitragslöschung',
  '<strong>Move</strong> content' => 'Inhalt <strong>verschieben</strong>',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> zu diesem Beitrag',
  'Add a member to notify' => 'Ein Mitglied zur Benachrichtigung hinzufügen',
  'Archived' => 'Archiviert',
  'Back to stream' => 'Zurück zum Stream',
  'Cancel' => 'Abbrechen',
  'Cancel Edit' => 'Bearbeitung abbrechen',
  'Content' => 'Inhalte',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Inhalts-Tag mit ungültiger contentcontainer_id zugewiesen.',
  'Content has been moved to {spacename}' => 'Inhalt wurde verschoben in den Space {spacename}',
  'Content visibility' => 'Sichtbarkeit von Inhalten',
  'Could not delete content!' => 'Inhalt konnte nicht gelöscht werden!',
  'Could not delete content: Access denied!' => 'Inhalt konnte nicht gelöscht werden: Zugriff verweigert!',
  'Could not find requested content!' => 'Konnte den angeforderten Inhalt nicht finden!',
  'Could not load requested object!' => 'Konnte das angeforderte Objekt nicht laden!',
  'Created by me' => 'Von mir erstellt',
  'Creation time' => 'Erstellzeit',
  'Delete' => 'Löschen',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Möchtest du diesen Beitrag wirklich löschen? Alle damit verbundenen "Gefällt mir"-Angaben und Kommentare sind dann nicht mehr verfügbar!',
  'Edit' => 'Bearbeiten',
  'Filter' => 'Filter',
  'Include archived content' => 'Archivierte Inhalte einschließen',
  'Invalid content id given!' => 'Ungültige Inhalts-ID angegeben!',
  'Invalid request method!' => 'Unzulässige Anfragemethode!',
  'Invalid space selection.' => 'Ungültige Auswahl des Space.',
  'Last update' => 'Letzte Aktualisierung',
  'Load more' => 'Mehr laden',
  'Make private' => 'Ändern in privat',
  'Make public' => 'Ändern in öffentlich',
  'Maximum number of pinned items reached!

You can pin to top only two items at once.
To however pin this item, unpin another before!' => 'Maximale Anzahl der angehefteten Elemente erreicht! Du kannst nur zwei Elemente gleichzeitig anheften. Um dieses Element dennoch anzuheften, löse vorher ein anderes!',
  'Move content' => 'Inhalt verschieben',
  'Move to archive' => 'Ins Archiv',
  'No matches with your selected filters!' => 'Die ausgewählten Filterkriterien ergaben keine Übereinstimmung!',
  'None' => 'Keine',
  'Nothing here yet!' => 'Derzeit keine Inhalte!',
  'Notify members' => 'Informiere Mitglieder',
  'Only private content' => 'Nur private Inhalte',
  'Only public content' => 'Nur öffentliche Inhalte',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Oben anheften',
  'Pinned' => 'Angeheftet',
  'Public' => 'Öffentlich',
  'Submit' => 'Abschicken',
  'Tag' => 'Tag',
  'Target Space' => 'Zielspace',
  'The author of this content is not allowed to create private content within the selected space.' => 'Der Autor dieses Inhaltes hat keine Berechtigung, im ausgewählten Space private Inhalte zu erstellen.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Der Autor dieses Inhaltes hat keine Berechtigung, im ausgewählten Space öffentliche Inhalte zu erstellen.',
  'The content can\'t be moved to its current space.' => 'Der Inhalt kann nicht in seinen derzeitigen Space verschoben werden.',
  'The content has been archived.' => 'Der Inhalt wurde archiviert.',
  'The content has been deleted.' => 'Der Inhalt wurde gelöscht.',
  'The content has been unarchived.' => 'Der Inhalt wurde dearchiviert.',
  'The given name is already in use.' => 'Der eingegebene Name wird bereits verwendet.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Das Modul {moduleName} ist im Zielspace nicht aktiviert.',
  'This action is disabled!' => 'Diese Aktion ist deaktiviert!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Dieser Inhaltstyp kann wegen einer fehlenden Modul-ID-Einstellung nicht verschoben werden.',
  'This content type can\'t be moved.' => 'Dieser Inhaltstyp kann nicht verschoben werden.',
  'This space is archived.' => 'Dieser Space ist archiviert.',
  'This space is not visible!' => 'Dieser Space ist nicht sichtbar!',
  'Topics' => 'Tags',
  'Turn off notifications' => 'Benachrichtigungen abschalten',
  'Turn on notifications' => 'Benachrichtigungen aktivieren',
  'Unarchive' => 'Aus dem Archiv',
  'Unpin' => 'Lösen',
  'Updated' => 'Aktualisiert',
  'Where I\'m involved' => 'Wo ich involviert bin',
  'With file attachments' => 'Mit Dateianhängen',
  'You do not have the permission to move this content to the given space.' => 'Du hast keine Berechtigung, den Inhalt in den ausgewählten Space zu verschieben.',
  'You do not have the permission to move this content.' => 'Du hast keine Berechtigung diesen Inhalt zu verschieben.',
  'Your last edit state has been saved!' => 'Dein letzter Bearbeitungsstand wurde gespeichert.',
  'in' => 'in',
);

==> humhub-1.6.3.tar.gz: humhub-1.6.3/protected/humhub/modules/content/messages/de/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Kann auch von Benutzern gesehen werden, die kein Mitglied des Spaces sind.)',
  '<strong>Confirm</strong> post deletion' => '<strong>Bestätige</strong> Beitragslöschung',
  '<strong>Move</strong> content' => 'Inhalt <strong>verschieben</strong>',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> zu diesem Beitrag',
  'Add a member to notify' => 'Ein Mitglied zur Benachrichtigung hinzufügen',
  'Archived' => 'Archiviert',
  'Back to stream' => 'Zurück zum Stream',
  'Cancel' => 'Abbrechen',
  'Cancel Edit' => 'Bearbeitung abbrechen',
  'Content' => 'Inhalte',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Inhalts-Tag mit ungültiger contentcontainer_id zugewiesen.',
  'Content has been moved to {spacename}' => 'Inhalt wurde verschoben in den Space {spacename}',
  'Content visibility' => 'Sichtbarkeit von Inhalten',
  'Could not delete content!' => 'Inhalt konnte nicht gelöscht werden!',
  'Could not delete content: Access denied!' => 'Inhalt konnte nicht gelöscht werden: Zugriff verweigert!',
  'Could not find requested content!' => 'Konnte den angeforderten Inhalt nicht finden!',
  'Created by me' => 'Von mir erstellt',
  'Creation time' => 'Erstellzeit',
  'Delete' => 'Löschen',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Möchtest du diesen Beitrag wirklich löschen? Alle damit verbundenen "Gefällt mir"-Angaben und Kommentare sind dann nicht mehr verfügbar!',
  'Edit' => 'Bearbeiten',
  'Filter' => 'Filter',
  'Invalid content id given!' => 'Ungültige Inhalts-ID angegeben!',
  'Invalid request method!' => 'Unzulässige Anfragemethode!',
  'Invalid space selection.' => 'Ungültige Auswahl des Space.',
  'Last update' => 'Letzte Aktualisierung',
  'Load more' => 'Mehr laden',
  'Make private' => 'Ändern in privat',
  'Make public' => 'Ändern in öffentlich',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Maximale Anzahl angehefteter Inhalte erreicht!<br />Du kannst bist zu {count} Inhalte gleichzeitig anheften.',
  'Move content' => 'Inhalt verschieben',
  'Move to archive' => 'Ins Archiv',
  'No matches with your selected filters!' => 'Die ausgewählten Filterkriterien ergaben keine Übereinstimmung!',
  'None' => 'Keine',
  'Nothing here yet!' => 'Derzeit keine Inhalte!',
  'Notify members' => 'Informiere Mitglieder',
  'Only private content' => 'Nur private Inhalte',
  'Only public content' => 'Nur öffentliche Inhalte',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Oben anheften',
  'Pinned' => 'Angeheftet',
  'Public' => 'Öffentlich',
  'Specify who can see this content.' => 'Lege fest, wer diesen Inhalt sehen kann.',
  'Submit' => 'Abschicken',
  'Tag' => 'Tag',
  'Target Space' => 'Zielspace',
  'The author of this content is not allowed to create private content within the selected space.' => 'Der Autor dieses Inhaltes hat keine Berechtigung, im ausgewählten Space private Inhalte zu erstellen.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Der Autor dieses Inhaltes hat keine Berechtigung, im ausgewählten Space öffentliche Inhalte zu erstellen.',
  'The author of this content is not allowed to create this type of content within this space.' => 'Der Autor des Inhalts darf keine Inhalte diesen Typs im Space erstellen.',
  'The content can\'t be moved to its current space.' => 'Der Inhalt kann nicht in seinen derzeitigen Space verschoben werden.',
  'The content has been archived.' => 'Der Inhalt wurde archiviert.',
  'The content has been deleted.' => 'Der Inhalt wurde gelöscht.',
  'The content has been unarchived.' => 'Der Inhalt wurde dearchiviert.',
  'The given name is already in use.' => 'Der eingegebene Name wird bereits verwendet.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Das Modul {moduleName} ist im Zielspace nicht aktiviert.',
  'This action is disabled!' => 'Diese Aktion ist deaktiviert!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Dieser Inhaltstyp kann wegen einer fehlenden Modul-ID-Einstellung nicht verschoben werden.',
  'This content type can\'t be moved.' => 'Dieser Inhaltstyp kann nicht verschoben werden.',
  'This space is archived.' => 'Dieser Space ist archiviert.',
  'This space is not visible!' => 'Dieser Space ist nicht sichtbar!',
  'Topics' => 'Tags',
  'Turn off notifications' => 'Benachrichtigungen abschalten',
  'Turn on notifications' => 'Benachrichtigungen aktivieren',
  'Unarchive' => 'Aus dem Archiv',
  'Unpin' => 'Lösen',
  'Updated' => 'Aktualisiert',
  'Where I\'m involved' => 'Wo ich involviert bin',
  'With file attachments' => 'Mit Dateianhängen',
  'You do not have the permission to move this content to the given space.' => 'Du hast keine Berechtigung, den Inhalt in den ausgewählten Space zu verschieben.',
  'You do not have the permission to move this content.' => 'Du hast keine Berechtigung diesen Inhalt zu verschieben.',
  'Your last edit state has been saved!' => 'Dein letzter Bearbeitungsstand wurde gespeichert.',
  'in' => 'in',
);
